@@ -617,9 +617,14 @@ register_Color4()
         .def("__rmul__", &mulTuple<T>)
         .def("__idiv__", &idiv<T>,return_internal_reference<>())
         .def("__idiv__", &idivT<T>,return_internal_reference<>())
+        .def("__itruediv__", &idiv<T>,return_internal_reference<>())
+        .def("__itruediv__", &idivT<T>,return_internal_reference<>())
         .def("__div__", &div<T>)
         .def("__div__", &divT<T>)
         .def("__div__", &divTupleL<T>)
+        .def("__truediv__", &div<T>)
+        .def("__truediv__", &divT<T>)
+        .def("__truediv__", &divTupleL<T>)
         .def("__rdiv__", &divTupleR<T>)  
         .def("__rdiv__", &divTR<T>)
         .def("__lt__", &lessThan<T>)
