@@ -1014,10 +1014,17 @@ register_Vec2()
         .def("__div__", &Vec2_divTuple<T,tuple>)
         .def("__div__", &Vec2_divTuple<T,list>)
         .def("__div__", &Vec2_divT<T>)
+        .def("__truediv__", &Vec2_div<T,int>)
+        .def("__truediv__", &Vec2_div<T,float>)
+        .def("__truediv__", &Vec2_div<T,double>)
+        .def("__truediv__", &Vec2_divTuple<T,tuple>)
+        .def("__truediv__", &Vec2_divTuple<T,list>)
+        .def("__truediv__", &Vec2_divT<T>)
         .def("__rdiv__", &Vec2_rdivTuple<T,tuple>)
         .def("__rdiv__", &Vec2_rdivTuple<T,list>)
         .def("__rdiv__", &Vec2_rdivT<T>)
         .def("__idiv__", &Vec2_idivObj<T>,return_internal_reference<>())
+        .def("__itruediv__", &Vec2_idivObj<T>,return_internal_reference<>())
         .def("__xor__", &Vec2_dot<T>)
         .def("__mod__", &Vec2_cross<T>)
         .def(self == self)
@@ -1077,7 +1084,9 @@ Vec2Array_get(FixedArray<IMATH_NAMESPACE::Vec2<T> > &va)
 }
 
 template <class T>
-static IMATH_NAMESPACE::Vec2<T> Vec2Array_min(const FixedArray<Imath::Vec2<T> > &a) {
+static IMATH_NAMESPACE::Vec2<T>
+Vec2Array_min(const FixedArray<IMATH_NAMESPACE::Vec2<T> > &a)
+{
     Vec2<T> tmp(Vec2<T>(0));
     size_t len = a.len();
     if (len > 0)
@@ -1093,7 +1102,9 @@ static IMATH_NAMESPACE::Vec2<T> Vec2Array_min(const FixedArray<Imath::Vec2<T> >
 }
 
 template <class T>
-static IMATH_NAMESPACE::Vec2<T> Vec2Array_max(const FixedArray<Imath::Vec2<T> > &a) {
+static IMATH_NAMESPACE::Vec2<T>
+Vec2Array_max(const FixedArray<IMATH_NAMESPACE::Vec2<T> > &a)
+{
     Vec2<T> tmp(Vec2<T>(0));
     size_t len = a.len();
     if (len > 0)
@@ -1109,7 +1120,9 @@ static IMATH_NAMESPACE::Vec2<T> Vec2Array_max(const FixedArray<Imath::Vec2<T> >
 }
 
 template <class T>
-static IMATH_NAMESPACE::Box<Imath::Vec2<T> > Vec2Array_bounds(const FixedArray<Imath::Vec2<T> > &a) {
+static IMATH_NAMESPACE::Box<IMATH_NAMESPACE::Vec2<T> >
+Vec2Array_bounds(const FixedArray<IMATH_NAMESPACE::Vec2<T> > &a)
+{
     Box<Vec2<T> > tmp;
     size_t len = a.len();
     for (size_t i=0; i < len; ++i)
@@ -1118,7 +1131,7 @@ static IMATH_NAMESPACE::Box<Imath::Vec2<T> > Vec2Array_bounds(const FixedArray<I
 }
 
 template <class T>
-class_<FixedArray<Imath::Vec2<T> > >
+class_<FixedArray<IMATH_NAMESPACE::Vec2<T> > >
 register_Vec2Array()
 {
     using boost::mpl::true_;
@@ -1150,7 +1163,9 @@ register_Vec2Array()
     generate_member_bindings<op_mul<IMATH_NAMESPACE::Vec2<T>,T>,  true_>(vec2Array_class,"__rmul__","x*self", boost::python::args("x"));
     generate_member_bindings<op_imul<IMATH_NAMESPACE::Vec2<T>,T>, true_>(vec2Array_class,"__imul__","self*=x",boost::python::args("x"));
     generate_member_bindings<op_div<IMATH_NAMESPACE::Vec2<T>,T>,  true_>(vec2Array_class,"__div__" ,"self/x", boost::python::args("x"));
+    generate_member_bindings<op_div<IMATH_NAMESPACE::Vec2<T>,T>,  true_>(vec2Array_class,"__truediv__" ,"self/x", boost::python::args("x"));
     generate_member_bindings<op_idiv<IMATH_NAMESPACE::Vec2<T>,T>, true_>(vec2Array_class,"__idiv__","self/=x",boost::python::args("x"));
+    generate_member_bindings<op_idiv<IMATH_NAMESPACE::Vec2<T>,T>, true_>(vec2Array_class,"__itruediv__","self/=x",boost::python::args("x"));
 
     decoratecopy(vec2Array_class);
 
