@@ -969,6 +969,7 @@ register_Vec3()
         .def("__imul__", &Vec3_imulV<T, double>,return_internal_reference<>())
         .def("__imul__", &Vec3_imulT<T>,return_internal_reference<>())
         .def("__div__", &Vec3_Vec3_divT<T>)
+        .def("__truediv__", &Vec3_Vec3_divT<T>)
         .def("__mul__", &Vec3_mulM33<T, float>)
         .def("__mul__", &Vec3_mulM33<T, double>)
         .def("__mul__", &Vec3_mulM44<T, float>)
@@ -980,10 +981,17 @@ register_Vec3()
         .def("__div__", &Vec3_divTuple<T,tuple>)
         .def("__div__", &Vec3_divTuple<T,list>)
         .def("__div__", &Vec3_divT<T>)
+        .def("__truediv__", &Vec3_div<T,int>)
+        .def("__truediv__", &Vec3_div<T,float>)
+        .def("__truediv__", &Vec3_div<T,double>)
+        .def("__truediv__", &Vec3_divTuple<T,tuple>)
+        .def("__truediv__", &Vec3_divTuple<T,list>)
+        .def("__truediv__", &Vec3_divT<T>)
         .def("__rdiv__", &Vec3_rdivTuple<T,tuple>)
         .def("__rdiv__", &Vec3_rdivTuple<T,list>)
         .def("__rdiv__", &Vec3_rdivT<T>)
         .def("__idiv__", &Vec3_idivObj<T>,return_internal_reference<>())
+        .def("__itruediv__", &Vec3_idivObj<T>,return_internal_reference<>())
         .def("__xor__", &Vec3_dot<T>)
         .def("__mod__", &Vec3_cross<T>)
         .def(self == self)
