@@ -951,6 +951,7 @@ register_Vec4()
         .def("__imul__", &Vec4_imulV<T, double>,return_internal_reference<>())
         .def("__imul__", &Vec4_imulT<T>,return_internal_reference<>())
         .def("__div__", &Vec4_Vec4_divT<T>)
+        .def("__truediv__", &Vec4_Vec4_divT<T>)
         .def("__mul__", &Vec4_mulM44<T, float>)
         .def("__mul__", &Vec4_mulM44<T, double>)
         .def("__mul__", &Vec4_Vec4_mulT<T>)
@@ -960,10 +961,17 @@ register_Vec4()
         .def("__div__", &Vec4_divTuple<T,tuple>)
         .def("__div__", &Vec4_divTuple<T,list>)
         .def("__div__", &Vec4_divT<T>)
+        .def("__truediv__", &Vec4_div<T,int>)
+        .def("__truediv__", &Vec4_div<T,float>)
+        .def("__truediv__", &Vec4_div<T,double>)
+        .def("__truediv__", &Vec4_divTuple<T,tuple>)
+        .def("__truediv__", &Vec4_divTuple<T,list>)
+        .def("__truediv__", &Vec4_divT<T>)
         .def("__rdiv__", &Vec4_rdivTuple<T,tuple>)
         .def("__rdiv__", &Vec4_rdivTuple<T,list>)
         .def("__rdiv__", &Vec4_rdivT<T>)
         .def("__idiv__", &Vec4_idivObj<T>,return_internal_reference<>())
+        .def("__itruediv__", &Vec4_idivObj<T>,return_internal_reference<>())
         .def("__xor__", &Vec4_dot<T>)
         .def(self == self)
         .def(self != self)
